@@ -273,7 +273,7 @@ class AwsTemporaryStorage(TemporaryStorage):
             datastream_name,
             prev_date,
             next_date,
-            filetype=DatastreamStorage.default_file_type,
+            filetype=self.datastream_storage.default_file_type,
         )
 
         previous_filepath = None
@@ -411,7 +411,7 @@ class AwsStorage(DatastreamStorage):
                 storage_paths.append(file)
 
         if filetype is not None:
-            filter_func = DatastreamStorage.file_filters[filetype]
+            filter_func = self.file_filters[filetype]
             storage_paths = list(filter(filter_func, storage_paths))
 
         return sorted(storage_paths)
